<?php

namespace App\Http\Controllers;
use DB;
use Session;
use Storage;
use Carbon\Carbon;
use Auth;

use App\Page;
use App\Post;
use App\Category;
use App\Module;
use App\ThemePosition;

use Illuminate\Http\Request;

class ModuleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:module-list|module-create|module-edit|module-delete', ['only' => ['index','store']]);
         $this->middleware('permission:module-create', ['only' => ['create','store']]);
         $this->middleware('permission:module-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:module-delete', ['only' => ['destroy']]);

        // TinyMCE
        $tm[0]['selector'] = 'body';
        $tm[0]['upload_url'] = 'modules';
        $tm[0]['field_height'] = '500';

        $this->tm = $tm;

        // Upload folder
        $this->folder = 'modules';
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // page header
        $title = __('dashboard.title_modules');
        $route = route('modules.create');
        $pageType = 'index';
        $canCreate = 'module-create';
        $canExport = null;

        $modules = Module::orderBy('created_at','DESC')->paginate(10);

        return view('modules.index',compact('title','route','pageType','canCreate','canExport',
                                            'modules'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // page header
        $title = __('dashboard.title_modules');
        $route = route('modules.index');
        $pageType = 'create';

        $tm = $this->tm;

        // ThemePositions
        $themePositions = ThemePosition::all();

        // Category SEL
        $categories_SEL = Category::categories_SEL();
        $categoriesForAttribute = array();
        $categoryDATA = array();

        // Posts
        $pages = Page::orderBy('created_at','DESC')->get();

        return view('modules.create',compact('title','route','pageType','tm',
                                            'themePositions',
                                            'categories_SEL','categoriesForAttribute','categoryDATA',
                                            'pages'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $this->validate($request, [
            'title' => 'required',
            'theme_position_id' => 'required'
        ]);

        $module = Module::create([
            'theme_position_id' => $request->input('theme_position_id'),
            'post_id' => $request->input('post_id'),
            'page_id' => $request->input('page_id'),
            'category_id' => $request->input('category_id'),
            'no_of_posts' => $request->input('no_of_posts'),
            'menu_id' => $request->input('menu_id'),
            'title' => $request->input('title'),
            'body' => $request->input('body'),
            'module_image' => $request->input('module_image'),
            'module_url' => $request->input('module_url'),
            'module_url_target' => $request->input('module_url_target'),
            'module_anchor' => $request->input('module_anchor'),
            'back_color' => $request->input('back_color'),
            'back_image' => $request->input('back_image'),
            'status' => $request->input('status'),
            'module_order' => $request->input('module_order')
        ]);

        // IMG upload - Module Image
        if (null !== request('module_image')):

            $file = $request->file('module_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$module->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);

            $moduleIMG = Module::where('id',$module->id)
                                    ->update([
                                        'module_image' => $imgNAME
                                    ]);
        endif;

        // IMG upload - Module Back Image
        if (null !== request('back_image')):

            $file = $request->file('back_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$module->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);

            $moduleBackIMG = Module::where('id',$module->id)
                                    ->update([
                                        'back_image' => $imgNAME
                                    ]);
        endif;
    
        return redirect()->route('modules.index')
                        ->with('success','Module created successfully');

    }

    
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // page header
        $title = __('dashboard.title_modules');
        $route = route('modules.index');
        $pageType = 'show';

        $module = Module::find($id);
    
        return view('modules.show',compact('title','route','pageType',
                                                'module'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // page header
        $title = __('dashboard.title_modules');
        $route = route('modules.index');
        $pageType = 'edit';

        // TinyMCE
        $tm = $this->tm;

        // ThemePositions
        $themePositions = ThemePosition::orderBy('created_at','DESC')->get();

        $module = Module::find($id);

        // Category SEL
        $categories_SEL = Category::categories_SEL();
        $categoriesForAttribute = array();
        $categoryDATA = new Category;

        // Posts
        $pages = Page::all();
    
        return view('modules.edit',compact('title','route','pageType','tm',
                                            'categories_SEL','categoriesForAttribute','categoryDATA',
                                            'pages',
                                            'themePositions',
                                            'module'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {   

        $this->validate($request, [
            'title' => 'required',
            'theme_position_id' => 'required'
        ]);
   
        $module = Module::find($id);

        $module->theme_position_id = $request->input('theme_position_id');
        $module->post_id = $request->input('post_id');
        $module->page_id = $request->input('page_id');
        $module->category_id = $request->input('category_id');
        $module->no_of_posts = $request->input('no_of_posts');
        $module->title = $request->input('title');
        $module->body = $request->input('body');
        $module->module_url = $request->input('module_url');
        $module->module_url_target = $request->input('module_url_target');
        $module->module_anchor = $request->input('module_anchor');
        $module->back_color = $request->input('back_color');
        $module->status = $request->input('status');
        $module->module_order = $request->input('module_order');

        

        // IMG upload - Module Image
        if (null !== request('module_image')):

            $file = $request->file('module_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$module->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);

            $moduleIMG = Module::where('id',$module->id)
                                    ->update([
                                        'module_image' => $imgNAME
                                    ]);
        endif;

        // IMG upload - Module Back Image
        if (null !== request('back_image')):

            $file = $request->file('back_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$module->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);

            $moduleBackIMG = Module::where('id',$module->id)
                                    ->update([
                                        'back_image' => $imgNAME
                                    ]);
        endif;

        $module->save();
    
        return redirect()->route('modules.index')
                        ->with('success','Module updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("modules")->where('id',$id)->delete();

        return redirect()->route('modules.index')
                        ->with('success','Module deleted successfully');
    }
}
