<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use DB;

use App\ResultGroup;

class ResultGroupController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:resultgroup-list|resultgroup-create|resultgroup-edit|resultgroup-delete', ['only' => ['index','store']]);
         $this->middleware('permission:resultgroup-create', ['only' => ['create','store']]);
         $this->middleware('permission:resultgroup-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:resultgroup-delete', ['only' => ['destroy']]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // page header
        $title = __('dashboard.title_results');
        //$route = route('results');
        $route = route('results-by-points.index');
        $pageType = 'create';

        return view('result-groups.create',compact('title','route','pageType'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required|unique:result_groups,title',
            'group_order' => 'required'
        ]);
    
        $resultGroup = ResultGroup::create([
            'title' => $request->input('title'),
            'group_order' => $request->input('group_order')
        ]);
    
        return redirect()->route('results-by-points.index')
                        ->with('success','Group created successfully');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // page header
        $title = __('dashboard.title_results');
        $route = route('results-by-points.index');
        // $route = route('results.index');
        $pageType = 'edit';

        $resultGroup = ResultGroup::find($id);
    
        return view('result-groups.edit',compact('title','route','pageType',
                                                    'resultGroup'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'title' => 'required',
        ]);
    
        $resultGroup = ResultGroup::find($id);
        $resultGroup->title = $request->input('title');
        $resultGroup->group_order = $request->input('group_order');
        $resultGroup->save();
    
        return redirect()->route('results-by-points.index')
                        ->with('success','Group updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("result_groups")->where('id',$id)->delete();

        return redirect()->route('results-by-points.index')
                        ->with('success','Group deleted successfully');
    }
}
