<?php

namespace App\Http\Controllers;

use DB;
use Illuminate\Http\Request;

use App\Settings;

class SettingsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:settings-list|settings-create|settings-edit|settings-delete', ['only' => ['index','store']]);
         $this->middleware('permission:settings-create', ['only' => ['create','store']]);
         $this->middleware('permission:settings-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:settings-delete', ['only' => ['destroy']]);

        // Upload folder
        $this->folder = 'settings';
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // page header
        $title = __('dashboard.title_settings');
        $route = route('settings.create');
        $pageType = 'index';
        $canCreate = 'settings-create';
        $canExport = null;

        $settings = Settings::orderBy('created_at','DESC')->paginate(10);

        return view('settings.index',compact('title','route','pageType','canCreate','canExport',
                                                        'settings'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // page header
        $title = __('dashboard.title_settings');
        $route = route('settings.index');
        $pageType = 'create';

        // Settings groups
        $groups = Settings::settingsGroups();

        // Settings field types
        $fieldTypes = Settings::settingsFieldTypes();

        return view('settings.create',compact('title','route','pageType',
                                                'groups','fieldTypes'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $this->validate($request, [
            'key_clean' => 'required|unique:settings,key_clean',
            'display_name' => 'required',
            'type' => 'required',
            'group' => 'required'
        ]);

        $settings = Settings::create([
            'key_name' => $request->input('group').'.'.$request->input('key_clean'),
            'key_clean' => $request->input('key_clean'),
            'display_name' => $request->input('display_name'),
            'order' => $request->input('order'),
            'type' => $request->input('type'),
            'group' => $request->input('group')
        ]);

        
        return redirect()->route('settings.index')
                        ->with('success','Setting created successfully');

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // page header
        $title = __('dashboard.title_settings');
        $route = route('settings.index');
        $pageType = 'edit';

        // Settings groups
        $groups = Settings::settingsGroups();

        // Settings field types
        $fieldTypes = Settings::settingsFieldTypes();

        $setting = Settings::find($id);
    
        return view('settings.edit',compact('title','route','pageType',
                                            'groups','fieldTypes',
                                            'setting'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {   

        $this->validate($request, [
            'key_clean' => 'required',
            'display_name' => 'required',
            'type' => 'required',
            'group' => 'required'
        ]);
   
        $setting = Settings::find($id);
        $setting->key_name = $request->input('group').'.'.$request->input('key_clean');
        $setting->key_clean = $request->input('key_clean');
        $setting->display_name = $request->input('display_name');
        $setting->order = $request->input('order');
        $setting->type = $request->input('type');
        $setting->group = $request->input('group');        

        $setting->save();
    
        return redirect()->route('settings.index')
                        ->with('success','Setting updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("settings")->where('id',$id)->delete();

        return redirect()->route('settings.index')
                        ->with('success','Setting deleted successfully');
    }
}
