<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Rap2hpoutre\FastExcel\FastExcel;
use Carbon\Carbon;
use DB;
use URL;

use App\Submission;

class SubmissionExportController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:submission-export', ['only' => ['export']]);
    }


    /**
     * Export submissions.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function export(Request $request)
    {

        $submissionStatuses = Submission::submissionStatus();

        $builder = DB::table('submissions as s')
                        ->join('users as u','u.id','s.user_id');

        if(null !== $request->input('status')):

            $search_status = $request->input('status');

            $builder->where('s.status',$search_status);

        endif;

        if(null !== $request->input('srch_from')):

            $search_date_from = date('Y-m-d', strtotime($request->input('srch_from')));

            $builder->where('s.created_at','>',$search_date_from);

        endif;

        if(null !== $request->input('srch_to')):

            $search_date_to = date('Y-m-d', strtotime($request->input('srch_to'). ' +1 day'));

            $builder->where('s.created_at','<=',$search_date_to);

        endif;

        $submissions = $builder->select(
            's.id as id',
            's.user_id as user_id',
            'u.name as user_name',
            'u.last_name as user_last_name',
            'u.last_name as user_last_name',
            'u.phone as user_phone',
            'u.email as user_email',
            'u.address as user_address',
            'u.city as user_city',
            's.bi as bi',
            's.points as points',
            's.source as source',
            's.image as image',
            's.status as status',
            's.created_at as created_at',
            's.updated_at as updated_at'
        )
        // ->orderBy('s.created_at','DESC')
        ->inRandomOrder()
        ->get();

        $fileName = 'Export_Submissions_'.date_format(Carbon::now(),"d.m.Y_H_i_s").'.xlsx';

        $finalForExport = array();

        if ($submissions):

            foreach ($submissions as $key => $submission) {

                $finalForExport[$key]['id'] = $submission->id;
                $finalForExport[$key]['name'] = $submission->user_name.' '.$submission->user_last_name;
                $finalForExport[$key]['phone'] = $submission->user_phone;
                $finalForExport[$key]['email'] = $submission->user_email;
                $finalForExport[$key]['address'] = $submission->user_address;
                $finalForExport[$key]['city'] = $submission->user_city;
                $finalForExport[$key]['kod'] = $submission->bi;
                // $finalForExport[$key]['points'] = $submission->points;
                $finalForExport[$key]['source'] = $submission->source;
                $finalForExport[$key]['status'] = $submissionStatuses[$submission->status];
                $finalForExport[$key]['created_at'] = date('d.m.Y H:i:s', strtotime($submission->created_at));
                $finalForExport[$key]['updated_at'] = date('d.m.Y H:i:s', strtotime($submission->updated_at));

            }

            $exp = collect($finalForExport);

            (new FastExcel($exp))->export(storage_path('app/public/submissions-export/').$fileName);

            $fileURL = URL::to('/').'/storage/submissions-export/'.$fileName;

        else:

            $exp = array();

            $fileURL = null;

        endif;

        $response =  array(
            'name' => $fileName,
            'file_url' => $fileURL
         );

        return response()->json($response);

    }
}
