@extends('dashboard.index')

@section('contentDashboard')

    @include('dashboard.page_header')

    @if (count($errors) > 0)
        <div class="alert alert-danger">
            <ul>
            @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
            @endforeach
            </ul>
        </div>
    @endif

    <div class="row">

        <div class="col col-xl-12">

            {!! Form::model($post, ['method' => 'PATCH','route' => ['posts.update', $post->id],'enctype'=>'multipart/form-data']) !!}

            <div class="card">

                <div class="card-body">

                    <div class="row">

                        <div class="col-xl-8">

                            <div class="row">
                                <div class="col mb-4">
                                    <div class="form-outline">
                                        <input type="text" id="formControlDefault" class="form-control" name="title" onBlur="convertToSlug('title')" value="{{ $post->title }}" />
                                        <label class="form-label" for="formControlDefault">@lang('dashboard.title_title')</label>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col">
                                    <div class="form-group">
                                        <label class="fw-bold">@lang('dashboard.title_excerpt'):</label>
                                        <textarea id="excerpt" name="excerpt">{!! $post->excerpt !!}</textarea>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col">
                                    <div class="form-group">
                                        <label class="fw-bold">@lang('dashboard.title_body'):</label>
                                        <textarea id="body" name="body">{!! $post->body !!}</textarea>
                                    </div>
                                </div>
                            </div>

                        </div>

                        <div class="col-xl-4">

                            <hr class="d-block d-xl-none">

                            <div class="row">
                                <div class="col-lg-4">

                                    <div class="row">
                                        <div class="col mb-4 ml-4">
                                            <div class="form-check form-switch">
                                                <input class="form-check-input" type="checkbox" role="switch" id="postStatus" name="status" value="1" {{ ($post->status == 1)? 'checked':'' }} />
                                                <label class="form-check-label" for="postStatus">@lang('dashboard.title_status')</label>
                                            </div>
                                        </div>
                                    </div>

                                </div>
                                <div class="col-lg-4">

                                    <div class="row">
                                        <div class="col mb-4 ml-4">
                                            <div class="form-check form-switch">
                                                <input class="form-check-input" type="checkbox" role="switch" id="postFeatured" name="featured" value="1" {{ ($post->featured == 1)? 'checked':'' }} />
                                                <label class="form-check-label" for="postFeatured">@lang('dashboard.title_featured')</label>
                                            </div>
                                        </div>
                                    </div>

                                </div>

                                <div class="col-lg-4">

                                    <div class="row">
                                        <div class="col">
                                            <label class="fw-bold mr-1">@lang('dashboard.title_author'):</label>{{ $post->author->name }} {{ $post->author->last_name }}
                                        </div>
                                    </div>

                                </div>
                            </div>

                            <div class="row">
                                <div class="col mb-4">
                                    <div class="form-outline">
                                        <input type="text" id="formControlDefault" class="form-control" name="slug" value="{{ $post->slug }}" />
                                        <label class="form-label" for="formControlDefault">@lang('dashboard.title_slug')</label>
                                    </div>
                                </div>
                            </div>

                            <hr>

                            @php
                                $categoryDATA->parent_id = $post->category_id;
                            @endphp
                            <div class="row">
                                <div class="col mb-4">
                                    <label class="fw-bold">@lang('dashboard.title_category')</label>
                                    <select class="form-select" aria-label="Parent Category" name="category_id">
                                        <option value="" selected>@lang('dashboard.title_choose')</option>
                                        @foreach ($categories_SEL as $category)
                                            @if ($category->parent_id == null)
                                            <option value="{{ $category->id }}" {{ ($category['active'] == '0')? 'disabled':'' }} {{ ($categoryDATA->parent_id == $category->id )? 'selected':'' }}>{{ $category->name }}</option>
                                            @endif
                                            @foreach ($category->childrenCategories as $childCategory)
                                                @include(
                                                    'categories.child_category',
                                                    [
                                                        'child_category' => $childCategory,
                                                        'parent_url' => $category->slug,
                                                        'before' => '-',
                                                        'selected_cat' => $categoriesForAttribute
                                                    ]
                                                    )
                                            @endforeach
                                        @endforeach
                                      </select>
                                </div>
                            </div>

                            <hr>

                            <div class="row">
                                <div class="col mb-4">
                                    <label class="form-label fw-bold" for="postImage">@lang('dashboard.title_image')</label>
                                    <input type="file" class="form-control" id="postImage" name="post_image"/>
                                </div>
                            </div>

                            @if($post->post_image != null)
                            <div class="row">
                                <div class="col mb-4">
                                
                                    <div class="dsplIMG">
                                        <img src="/storage/posts/{{ $post->post_image }}" class="img-fluid" title="{{ $post->title }}">
                                    </div>
                                    <div id="imgDELETE" class="btn btn-danger btn-sm mt-2" onclick="delIMG('posts','post_image',{{ $post->id }})"><i class="far fa-trash-alt"></i></div>

                                </div>
                            </div>
                            @endif

                            <hr>

                            <div class="row">
                                <div class="col">
                                    <div class="form-group">
                                        <label class="fw-bold" for="metaDesc">@lang('dashboard.title_meta_description')</label>
                                        <textarea class="form-control rounded-0" id="metaDesc" rows="5" name="meta_description">{{ $post->meta_description }}</textarea>
                                      </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col">
                                    <div class="form-group">
                                        <label class="fw-bold" for="metaDesc">@lang('dashboard.title_meta_keywords')</label>
                                        <textarea class="form-control rounded-0" id="metaDesc" rows="5" name="meta_keywords">{{ $post->meta_keywords }}</textarea>
                                      </div>
                                </div>
                            </div>

                        </div>

                    </div>

                </div>

                <div class="card-footer">

                    <div class="row">
                        <div class="col text-right">
                            <button type="submit" class="btn btn-primary px-5 col col-lg-6">@lang('dashboard.btn_submit')</button>
                        </div>
                    </div>

                </div>

            </div>

            {!! Form::close() !!}

        </div>

    </div>

    <tinymce
        :data_tm = "{{ json_encode($tm) }}"
    >
    </tinymce>

@endsection