<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\EditorController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Auth::routes();

Route::get('/', 'HomeController@index');
Route::post('posalji-kontakt','SendContarctController@sendContact');

Route::get('lista-dobitnika','ContestResultsController@results');

Route::group(['middleware' => ['role:Competitor']], function() {

    Route::get('profil','ProfilController@showProfile');
    Route::post('profil','ProfilController@updateProfile');

    Route::get('posalji-racun','SendReceiptController@showForm');
    Route::post('posalji-racun','SendReceiptController@uploadReceipt');

    Route::get('moje-prijave','MyApplicationsController@showApplications');

});

Route::group(['middleware' => ['role:Admin|Editor|Contest']], function() {
// Route::group(['middleware' => ['auth']], function() {

    Route::get('/dashboard', 'DashboardController@index')->name('dashboard');

    Route::group(['prefix' => 'dashboard'], function () {

        // User control
        Route::resource('roles','RoleController');
        Route::resource('permissions','PermissionController');
        Route::resource('users','UserController');

        // Content
        Route::resource('categories','CategoryController');
        Route::resource('posts','PostController');
        Route::resource('pages','PageController');

        Route::resource('modules','ModuleController');
        Route::resource('theme-positions','ThemePositionController');

        Route::resource('settings','SettingsController');

        Route::get('application','ApplicationController@index')->name('app.index');
        Route::post('application','ApplicationController@update')->name('app.update');

        // Route::resource('submissions','SubmissionController');
        
        Route::get('submissions/','SubmissionController@index')->name('submissions.index');

        Route::get('submissions/search','SubmissionController@search');
        Route::post('submissions/search','SubmissionController@search');

        Route::delete('submissions/{id}','SubmissionController@destroy')->name('submissions.destroy');

        Route::post('submissions/update-status','SubmissionController@updateStatus');

        Route::post('submissions/export','SubmissionExportController@export');


        Route::resource('competitors','CompetitorController');

        Route::get('profile','ProfileController@showProfile');
        Route::post('profile','ProfileController@updateProfile');

        Route::post('sms-request/info','SMSRequestController@info');

        Route::resource('results','ResultController');
        Route::resource('result-groups','ResultGroupController');
        Route::resource('result-items','ResultItemController');

        Route::resource('results-by-points','ResultsByPointsController');

        // Route::resource('products','ProductController');

        // TinyMCE image upload
        Route::post('/upload/{type}','UploadController@uploadIMG');

        // Delete Image
        Route::post('/delete/image','DeleteImageController@deleteIMG');

        // Find posts
        Route::post('/get-posts','PostSearchController@postsByCatID');

        Route::get('/editor', [EditorController::class, 'index'])->name('editor.index');
        Route::post('/editor', [EditorController::class, 'store'])->name('editor.store');

        Route::post('/upload-image', [EditorController::class, 'uploadImage']);
        // Route::post('/upload-image', [EditorController::class, 'uploadImage'])->name('editor.uploadImage');

    });
});

//clear ALL --------------------------------------------- //
//Set ALL
Route::get('/clearall', function() {
    $storageLink = Artisan::call('storage:link');

    $cacheClear = Artisan::call('cache:clear');
    $viewClear = Artisan::call('view:clear');
    $configClear = Artisan::call('config:cache');
    //$optimize = Artisan::call('optimize');
    $routeClear = Artisan::call('route:clear');


    return '<h1>All Done!!</h1>';
});

Route::get('/{pageSlug}', 'ContentController@procesContent')->where('pageSlug','^[a-zA-Z0-9-_\/]+$');